@@ -178,7 +178,11 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
     load = ImportQueue.objects.get(pk=importqueue_pk)
     
     destination = load.batch.destination
-    similar_load_qs = ImportQueue.objects.filter(batch__destination=destination, file=load.file)
+    similar_load_qs = ImportQueue.objects.filter(batch__destination=destination,
+                                                 file__state=load.file.state,
+                                                 file__year=load.file.year,
+                                                 file__file_type__source=load.file.file_type.source
+                                                 )
     similar_completed = similar_load_qs.filter(complete__isnull=False, status='SUCCESS')
     similar_started = similar_load_qs.filter(start__isnull=False)
     
@@ -307,9 +311,14 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
         
         if drop_intermediate_tables:
             drop_targets = [rawload, staging[0]]
-            logger.info('Dropping intermediate tables %s as part of load for %s' % (drop_targets, load))
+            logger.info('Dropping intermediate tables %s: %s' % (drop_targets, load))
             for dtbl in drop_targets:
-                pg_drop(cnxn, dtbl)
+                logger.info('Dropping %s as part of load %s' % (dtbl, load))
+                drop_result = pg_drop(cnxn, dtbl)
+                if drop_result == True:
+                    logger.info('Successfully dropped intermediate table %s: %s' % (dtbl, load))
+                else:
+                    logger.error('Failed to drop %s: %s' % (dtbl, load))
     
     # affected_rows will evaluate un-True in the case of any troubles
     if affected_rows:
